#include "led.h"

#define HEATLE_ENABLE_PIN     18
#define HEATLE_ENABLE_PIN_2   0

const struct device *dev;

int led_init() {
    dev = device_get_binding(LED_DEVICE);
    if (dev == NULL) {
        printk("Failed to init LED Device\r\n");
    }

    int ret = gpio_pin_configure(dev, LED_GREEN, GPIO_OUTPUT_LOW);
    if (ret < 0) {
        printk("failed to configure gpio green %d\r\n", ret);
        return -1;
    }

    ret = gpio_pin_configure(dev, LED_RED, GPIO_OUTPUT_LOW);
    if (ret < 0) {
        printk("failed to configure gpio red %d\r\n", ret);
        return -1;
    }

    ret = gpio_pin_configure(dev, LED_BLUE, GPIO_OUTPUT_HIGH);
    if (ret < 0) {
        printk("failed to configure gpio blue %d\r\n", ret);
        return -1;
    }

    ret = gpio_pin_configure(dev, HEATLE_ENABLE_PIN, GPIO_OUTPUT_HIGH);
    if (ret < 0) {
        printk("failed to configure gpio green %d\r\n", ret);
        return -1;
    }

    ret = gpio_pin_configure(dev, HEATLE_ENABLE_PIN_2, GPIO_OUTPUT_HIGH);
    if (ret < 0) {
        printk("failed to configure gpio green %d\r\n", ret);
        return -1;
    }

    gpio_pin_set(dev, HEATLE_ENABLE_PIN, 1);
    gpio_pin_set(dev, HEATLE_ENABLE_PIN_2, 1);

    return 0;
}

static bool led_state_red;
static bool led_state_blue;
static bool led_state_green;

int blink_red() {
    led_state_red = !led_state_red;
    gpio_pin_set(dev, LED_RED, led_state_red);
    k_msleep(600);
    led_state_red = !led_state_red;
    gpio_pin_set(dev, LED_RED, led_state_red);
    k_msleep(600);
    return 0;
}

int blink_blue() {
    led_state_blue = !led_state_blue;
    gpio_pin_set(dev, LED_BLUE, led_state_blue);
    k_msleep(600);
    led_state_blue = !led_state_blue;
    gpio_pin_set(dev, LED_BLUE, led_state_blue);
    k_msleep(600);
    return 0;
}

int blink_green() {
    led_state_green = !led_state_green;
    gpio_pin_set(dev, LED_GREEN, led_state_green);
    k_msleep(600);
    led_state_green = !led_state_green;
    gpio_pin_set(dev, LED_GREEN, led_state_green);
    k_msleep(600);
    return 0;
}

int toggle_red() {
    led_state_red = !led_state_red;
    gpio_pin_set(dev, LED_RED, led_state_red);
    return 0;
}

int toggle_blue() {
    led_state_blue = !led_state_blue;
    gpio_pin_set(dev, LED_BLUE, led_state_blue);
    return 0;
}

int toggle_green() {
    led_state_green = !led_state_green;
    gpio_pin_set(dev, LED_GREEN, led_state_green);
    return 0;
}

void led_deinit() {
    led_state_red = false;//false;
    led_state_blue = false;
    led_state_green = false;

    gpio_pin_set(dev, LED_RED, 0);
    gpio_pin_set(dev, LED_BLUE, 0);
    gpio_pin_set(dev, LED_GREEN, 0);
}