//
// Created by nrjn on 29.11.20.
//
/*
 * init led, act pin, ble adv
 */
#include <zephyr.h>
#include <device.h>
#include <drivers/gpio.h>
#include <sys/printk.h>

#include "rod.h"
#include "led.h"
#include "ntc.h"
#include "rod_ble.h"

#define ROD_ACT_GPIO_LABEL   "GPIO_0" // DT_GPIO_LABEL(SW0_NODE, gpios)
#define ROD_ACT_GPIO_PIN    5  //DT_GPIO_PIN(SW0_NODE, gpios)
#define ROD_ACT_GPIO_FLAGS    (GPIO_INPUT | GPIO_PULL_UP | GPIO_ACTIVE_LOW)// DT_GPIO_FLAGS(SW0_NODE, gpios))

const struct device *rod_act_device;
static struct gpio_callback rod_act_cb_data;

static bool state_active;

void rod_act_int_event(const struct device *dev, struct gpio_callback *cb,
                       uint32_t pins) {

    uint32_t state = gpio_pin_get_raw(dev, ROD_ACT_GPIO_PIN);

    if (state == 1) {
        /// ble on
        printk("ble on, advertising\r\n");
        if (!state_active) {
            rod_ble_adv_start();
            state_active = true;
        }
    } else {
        /// low power on
        printk("low power mode on, advertising stopped\r\n");
        if (state_active) {
//            rod_ble_adv_stop();
            state_active = false;
        }
    }
//    printk("Button pressed at %" PRIu32 "\n", k_cycle_get_32());
//    printk("PIN (%" PRIu32 ") STATUS %lu\r\n", pins, state);
}

int rod_init(void) {
    int ret;

    rod_act_device = device_get_binding(ROD_ACT_GPIO_LABEL);
    if (rod_act_device == NULL) {
        printk("Error: didn't find %s device\n", ROD_ACT_GPIO_LABEL);
        return 0;
    }

    ret = gpio_pin_configure(rod_act_device, ROD_ACT_GPIO_PIN, ROD_ACT_GPIO_FLAGS);
    if (ret != 0) {
        printk("Error %d: failed to configure %s pin %d\n",
               ret, ROD_ACT_GPIO_LABEL, ROD_ACT_GPIO_PIN);
        return 0;
    }
    ret = gpio_pin_interrupt_configure(rod_act_device,
                                       ROD_ACT_GPIO_PIN,
                                       GPIO_INT_EDGE_BOTH | GPIO_INT_DEBOUNCE);
    if (ret != 0) {
        printk("Error %d: failed to configure interrupt on %s pin %d\n",
               ret, ROD_ACT_GPIO_LABEL, ROD_ACT_GPIO_PIN);
        return 0;
    }

    gpio_init_callback(&rod_act_cb_data, rod_act_int_event, BIT(ROD_ACT_GPIO_PIN));
    gpio_add_callback(rod_act_device, &rod_act_cb_data);
    printk("Set up button at %s pin %d\n", ROD_ACT_GPIO_LABEL, ROD_ACT_GPIO_PIN);

    if (gpio_pin_get_raw(rod_act_device, ROD_ACT_GPIO_PIN)) {
        state_active = true;
    }

    led_deinit();
    return 0;
}

void rod_deinit(void) {

}

void rod_run() {
    int16_t temp;
    for (;;) {
//        if (state_active) {
        toggle_green();
        k_msleep(300);
        toggle_blue();
        k_msleep(300);
        toggle_red();
        k_msleep(300);
        get_temperature(&temp);
        rod_ble_update_data(temp);
//        } else {
//        led_deinit();
        k_msleep(100);
//            k_msleep(1000);
//        }

    }
}
