//
// Created by nrjn on 15.11.20.
//

#include "rod_ble.h"

#define DEVICE_NAME CONFIG_BT_DEVICE_NAME
#define DEVICE_NAME_LEN (sizeof(DEVICE_NAME) - 1)

static bool rod_adv;

struct bt_le_adv_param adv_parm = {
        .id = 0,
        .interval_min = BT_GAP_ADV_SLOW_INT_MIN,
        .interval_max = BT_GAP_ADV_SLOW_INT_MAX,
        .peer = NULL
};

/* Set Advertisement data */
const struct bt_data ad[] = {
        BT_DATA_BYTES(BT_DATA_FLAGS, BT_LE_AD_GENERAL),
        BT_DATA_BYTES(BT_DATA_UUID128_ALL, 0xC5, 0x20, 0x1F, 0xFD, 0xD7, 0x45, 0x47, 0x7D,
                      0x8E, 0x35, 0x8F, 0x16, 0x2A, 0xEA, 0xCD, 0x1D),
};

/* Set Scan Response data */
static const struct bt_data sd[] = {
        BT_DATA(BT_DATA_NAME_COMPLETE, DEVICE_NAME, DEVICE_NAME_LEN),
};

static void bt_ready(int err) {
    if (err) {
        printk("Bluetooth init failed (err %d)\n", err);
        return;
    }
    printk("Bluetooth initialized\n");
}


int rod_ble_init(void) {
    int err;

    printk("Starting Beacon Demo\n");

    /* Initialize the Bluetooth Subsystem */
    err = bt_enable(bt_ready);
    if (err) {
        printk("Bluetooth init failed (err %d)\n", err);
    }
    return rod_ble_adv_start();
}

int rod_ble_adv_start() {
    if (rod_adv) {
        return 0;
    }
    int err;
    /* Start advertising */
    err = bt_le_adv_start(&adv_parm, ad, ARRAY_SIZE(ad),
                          sd, ARRAY_SIZE(sd));
    if (err) {
        printk("Advertising failed to start (err %d)\n", err);
        return err;
    }
    printk("Advertising started\n");
    rod_adv = true;
    return err;
}

int rod_ble_adv_stop() {
    if (!rod_adv) {
        return 0;
    }
    int err;
    /* Stop advertising */
    err = bt_le_adv_stop();
    if (err) {
        printk("Advertising failed to stop (err %d)\n", err);
        return err;
    }
    rod_adv = false;
    return err;
}

int rod_ble_update_data(int data) {
    int tmp = data;
    const struct bt_data new_ad[] = {
            BT_DATA_BYTES(BT_DATA_FLAGS, BT_LE_AD_GENERAL),
            BT_DATA_BYTES(BT_DATA_UUID128_ALL, 0xC5, 0x20, 0x1F, 0xFD, 0xD7, 0x45, 0x47, 0x7D,
                          0x8E, 0x35, 0x8F, 0x16, 0x2A, 0xEA, 0xCD, 0x1D),
            BT_DATA_BYTES(BT_DATA_MANUFACTURER_DATA,
                          tmp),
    };
    int err = bt_le_adv_update_data(new_ad, ARRAY_SIZE(new_ad), sd, ARRAY_SIZE(sd));
    return err;
}